       real*8 TargetMassN  ! Number weighted average target mass number.  fixed value
       real*8 TargetAtomicN   !The same for average Z of the target.   fixed value
       real*8 TargetZ2        ! <Z^2> of the target
       integer TargetNucleonNo  !  target nucleon number at a collision. sampled at each collision
       real*8 TargetZ2_3rd  ! <Z>^(2/3).  Since <Z> is almost same as 7 or 8
c                    we simpley use this as <Z^2/3>
       real*8 TargetZ1_3rd  !  <Z>^(1/3).  same reason

       integer TargetProtonNo  !  target proton number  //     //
       real*8  TargetXs   ! inelastic xs for this target
       common /Zair/
     *  TargetMassN, TargetAtomicN, TargetZ2, TargetZ2_3rd,  
     *  TargetZ1_3rd, TargetXs,
     *  TargetNucleonNo, TargetProtonNo
 
	 save /Zair/






